/***************************************************************************
 *   Copyright (C) 2003 by Antonio Fasolato                                *
 *   Antonio.Fasolato@poste.it                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#ifndef CONFIGURATION_H
#define CONFIGURATION_H

#include <qstring.h>

/**
  * This is a singleton class, to save global settings into a KConfig object. I'm using a singleton because I need only one object of this class, and I need it to be created before all other objects.
  * @short A class to save settings
  * @author Antonio Fasolato
*/
class Configuration{
private:
    Configuration();
	Configuration(const Configuration&);

public:
	/**
	  * Retrieves the settings from where they are stored (~/.kde/share/config/potraceguirc in Linux)
	  * @short Retrieves the settings
	  */
	void read();
	/**
	  * Saves the settings where they should be stored (~/.kde/share/config/potraceguirc in Linux)
	  * @short Saves the settings
	  */
	void write() const;
	/**
	  * Restores the default settings (set at compile time)
	  * @short Reverts to defaults
	  */
	void defaultValues();

	QString potrace; /**< potrace's executable */
	QString viewer; /**< Viewer's command (I use ImageMagic by default, but any image viewer will suffice)*/
	bool preview; /**< If this is false, the previewer will not be launched*/

	/**
	  * Whith this function the single object of this class can be used (the first time it is called, the object will be created)
	  * @short This returns the single object of this class
	  * @returns A reference to the single object of the class
	  */
	friend Configuration& Conf();
};

Configuration& Conf();

#endif
