/***************************************************************************
 *   Copyright (C) 2003 by Antonio Fasolato                                *
 *   Antonio.Fasolato@poste.it                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
#ifndef OPTIONDIALOG_H
#define OPTIONDIALOG_H

#include "optionDialogBase.h"
#include "options.h"

/**
  *This dialog lets the user select potrace's various options (output, format...) for processing the selected image
  *@author Antonio Fasolato
  *@short Tracin properties dialog
  */
class OptionDialog : public OptionDialogBase
{
public:
	/**
	  * The only constructor: it takes an Options pointer, coming from the app's main window. At first this object contains nothing, but as the user changes it, more values are added. The options are kept in the main window in case the user wants to set the options in various times: when the options button is pressed, the window remembers the options set since now.
	  * @short Class constructor
	  */
    OptionDialog(Options &);

private slots:
	/**
	  * This opens a KFileDialog for choosing an output filename. The filter selects all potrace output: ps, eps, svg, pgm
	  * @short Selects the output file
	  */
    virtual void selectOutputFile();
	/**
	  * This function closes the options dialog, saving the preferences set for the image
	  * @short exits saving changes
	  */
    virtual void exitOk();
	/**
	  * Revert to the old settings for all the options. This change will take effect only exiting the dialog via the OK button.
	  * @short sets the options to their default values
	  */
    virtual void defaults();

private:
	Options &options;
	void initializeOptions(Options &);
	Options *createDefaultOptions();
};

#endif
